*   FUNCTION NOVMENU
*
*   Author:     John Jenkins -- 72441,3006
*
*   Purpose:    Pop a menu on the screen similar to Novell's
*
*   Pass:       T         - numeric; top coordinate for menu
*               L         - numeric; left coordinate for menu
*               Choices   - array; an array containing available menu options,
*                           with the first element being the menu title
*               ScrRest   - logical; T/F indicating if the screen is to be
*                           restored upon exit
*               Color1    - color string; menu frame color
*               Color2    - color string; menu options color
*               OldChoice - optional numeric; allows the menu to return to the previously
*                           selected choice.  If not passed, the first menu
*                           choice will be the default.
*
*   Returns:    zero if Esc is pressed; number of menu option selected otherwise
*
*   Notes:      The PgUp and PgDn keys are redefined as first and last menu
*               choice respectively, rather than exit keys.
*
*               The menu will be sized according to the largest ALLTRIMmed
*               array element.
*
*               No error checking...
*
*               Kudos to Rick Whitt for his public domain SCRNPLAY routines;
*               this function uses CHATTR for true shadowing.  These lines are
*               commented out; remove the asterisks if you have these routines.
*               If you don't have them, you can get them from:
*
*                        Rick Whitt, SysOp
*                       dBoard BBS - Winston-Salem, NC
*                       (919) 768-3043
*
*
*
*               Any questions or comments, you can direct them to
*
*                          John Jenkins - 72441,3006
*
*
*
*

FUNCTION NOVMENU
PARAM T,L,Choices,ScrRest,Color1,Color2,OldChoice
PRIVATE MainColor,MainScr,MWid,MLen,X,B,R,MnuTitle,ExitCh
ExitCh=IIF(PCOUNT()=6,1,OldChoice)                          && set default menu option
MWid=0
FOR X=1 TO LEN(Choices)
 MWid=MAX(MWid,LEN(ALLTRIM(Choices[X])))                    && find maximum width of array elements
NEXT X
MnuTitle=ALLTRIM(Choices[1])                                && get title from first array element
MLen=LEN(Choices)-1
TCent=(((MWid+4)-LEN(MnuTitle))/2)+L                        && center coordinate for the title
B=T+5+MLen
R=L+5+MWid
MainColor=SETCOLOR()
MainScr=SAVESCREEN(T,L,B,R)
SETCOLOR(Color1)
@ T,L SAY ""+REPLICATE("",2+MWid)+""                     && draw the menu
@ T+1,L SAY ""+SPACE(2+MWid)+""
@ T+1,TCent SAY MnuTitle
@ T+2,L SAY ""+REPLICATE("",2+MWid)+""
X=T+3
DO WHILE X<(MLen+T+3)
 @ X,L SAY " "
 @ X,L+3+MWid SAY ""
 X=X+1
ENDD
@ X,L SAY ""+REPLICATE("",2+MWid)+""

* CHGATTR(T+1,L+4+MWid,T+4+MLen,L+5+MWid,7,0)                 && adds true shadow with Rick Whitt's wonderful SCRNPLAY routine
* CHGATTR(T+4+MLen,L+1,T+4+MLen,L+5+MWid,7,0)

SETCOLOR(Color2)
@ T+3,L+2 TO X-1,L+2
DO WHIL .T.
 X=T+3
 Z=2
 DO WHILE X<(MLen+T+3)                                      && prompt each choice on the screen
  Choices[Z]=ALLTRIM(Choices[Z])+SPACE(MWid-LEN(ALLTRIM(Choices[Z])))
  @ X,L+3 PROMPT Choices[Z]
  X=X+1
  Z=Z+1
 ENDD
 MENU TO ExitCh                                             && wait for input
 IF (LAST()=27.OR.LAST()=13).OR.(LAST()>32.AND.LAST()<127)  && exit with Esc, Return or valid letter
  EXIT
 ELSEIF LAST()=18                                           && PgUp - first choice
  ExitCh=1
 ELSEIF LAST()=3                                            && PgDn - last choice
  ExitCh=MLen
 ENDIF
ENDD
SETCOLOR(MainColor)
IF ScrRest                                                  && restore screen if specified
 RESTSCREEN(T,L,B,R,MainScr)
ENDI
RETURN ExitCh                                               && return selected option

